==> xalan_1.8.orig.tar.gz: xml-xalan/c/src/xalanc/XPath/XStringAllocator.cpp <==
/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// Class header file.
#include "XStringAllocator.hpp"



XALAN_CPP_NAMESPACE_BEGIN



XStringAllocator::XStringAllocator(size_type	theBlockCount) :
	m_allocator(theBlockCount)
{
}



XStringAllocator::~XStringAllocator()
{
}



XStringAllocator::string_type*
XStringAllocator::createString(const XalanDOMString&	theString) 
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	string_type* const	theResult = new(theBlock) string_type(theString);

	m_allocator.commitAllocation(theBlock);

	return theResult;
}



XStringAllocator::string_type*
XStringAllocator::createString(const XalanDOMChar*	theString)
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	string_type* const	theResult = new(theBlock) string_type(theString);

	m_allocator.commitAllocation(theBlock);

	return theResult;
}



XStringAllocator::string_type*
XStringAllocator::createString(
			const XalanDOMChar*		theString,
			unsigned int			theLength)
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	string_type* const	theResult = new(theBlock) string_type(theString, theLength);

	m_allocator.commitAllocation(theBlock);

	return theResult;
}



XStringAllocator::string_type*
XStringAllocator::clone(const XString&	value)
{
	string_type* const		theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	value.clone(theBlock);

	m_allocator.commitAllocation(theBlock);

	return theBlock;
}



bool 
XStringAllocator::destroy(string_type*	theString)
{
	return m_allocator.destroyObject(theString);
}



void 
XStringAllocator::reset()
{
	m_allocator.reset();
}



XALAN_CPP_NAMESPACE_END

==> xalan_1.10.orig.tar.gz: xml-xalan/c/src/xalanc/XPath/XStringAllocator.cpp <==
/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// Class header file.
#include "XStringAllocator.hpp"



XALAN_CPP_NAMESPACE_BEGIN



XStringAllocator::XStringAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
	m_allocator(theManager, theBlockCount)
{
}



XStringAllocator::~XStringAllocator()
{
}



XStringAllocator::string_type*
XStringAllocator::createString(const XalanDOMString&	theString) 
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

    string_type* const	theResult = new(theBlock) string_type(theString, m_allocator.getMemoryManager());

	m_allocator.commitAllocation(theBlock);

	return theResult;
}



XStringAllocator::string_type*
XStringAllocator::createString(const XalanDOMChar*	theString)
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	string_type* const	theResult = new(theBlock) string_type(theString, m_allocator.getMemoryManager());

	m_allocator.commitAllocation(theBlock);

	return theResult;
}



XStringAllocator::string_type*
XStringAllocator::createString(
			const XalanDOMChar*		theString,
			unsigned int			theLength)
{
	string_type* const	theBlock = m_allocator.allocateBlock();
	assert(theBlock != 0);

	string_type* const	theResult = new(theBlock) string_type(theString, theLength, m_allocator.getMemoryManager());

	m_allocator.commitAllocation(theBlock);

	return theResult;
}





bool 
XStringAllocator::destroy(string_type*	theString)
{
	return m_allocator.destroyObject(theString);
}



void 
XStringAllocator::reset()
{
	m_allocator.reset();
}



XALAN_CPP_NAMESPACE_END
